"""
Basic system controller example

Change the sc_address variable to match your system controller.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

from ardrivers import arsystemcontroller

sc_address = 'GPIB0::1::INSTR'


# Function to query and display the current switch configuration
# Only the first 4 switches are queried, this can be changed based on
# How many switches are present.
def print_config(sc):
    for i in range(1, 5):
        print(f'Switch {i}: Position: {sc.query_switch(i)}')

    for i in range(1, 5):
        print(f'Open Drain {i}: {sc.query_open_drain(i)}')


# Create an AR_SC2000 object and initialize the VISA session
sc = arsystemcontroller.AR_SC2000()
sc.initialize(sc_address)

# Print the current configuration
print_config(sc)

# Set the switches to new positions
print('Setting switches...')
sc.set_switches([(1, 1), (2, 2), (3, 3), (4, 4)])

# Set the open drains
print('Setting open drains...')
sc.set_open_drains([(1, 1), (2, 0), (3, 1), (4, 0)])

# Print the configuration after switching
print_config(sc)

sc.local_mode()
sc.close()
