"""
Basic amplifier example

Change the amp_model and amp_address variables to match your amplifier.
If using an amplifier with an LCD touch panel, you can leave the model blank
and the class will default to the newest command set.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

from ardrivers import aramplifier
import time

amp_model = ''
amp_address = 'GPIB0::4::INSTR'
gain = 100


def printstate(amp):
    print('STATE: {0:016b}'.format(amp.read_state()))


# Create an AR_Amp object and initialize the VISA session
amp = aramplifier.AR_Amp(amp_model)
amp.initialize(amp_address)
print('*IDN:', amp.id_query())

# Reset
amp.reset()
time.sleep(1)
printstate(amp)

# Power on
print('Power on')
amp.power(1)
printstate(amp)

# Set mode to manual using a constant from the aramplifier module
amp.set_mode(aramplifier.MODE_MANUAL)
time.sleep(1)

# Set the RF gain
print('Setting gain to', gain)
amp.set_rf_gain(gain)
time.sleep(1)

# Query the RF gain
print('Querying RF gain:', amp.query_rf_gain())
time.sleep(1)

# Turn RF on
print('RF on')
amp.rf_output(1)
time.sleep(1)
printstate(amp)

# Read status
print('Forward Power: {}'.format(amp.query_forward_power()))
print('Reverse Power: {}'.format(amp.query_reverse_power()))
(pow_hours, rf_hours) = amp.query_operating_hours()
print('Power on hours: {}\nRF on hours: {}'.format(pow_hours, rf_hours))

# Turn RF off
print('RF off')
amp.rf_output(0)
time.sleep(1)

# Power off
print('Power off')
amp.power(0)
time.sleep(1)
printstate(amp)

# Check faults
print('Fault:', amp.read_fault())